@@ -36,8 +36,4 @@ def _load_jupyter_server_extension(server_app):
         JupyterLab application instance
     """
     setup_handlers(server_app)
-    server_app.log.info(
-        "Registered jupyterlab-optumi extension version "
-        + __version__
-        + " at URL path /optumi"
-    )
+    server_app.log.info("Registered jupyterlab-optumi extension version " + __version__ + " at URL path /optumi")
